@@ -2,7 +2,7 @@ package Plack::Middleware::Auth::WebID;
 
 {
 	$Plack::Middleware::Auth::WebID::AUTHORITY = 'cpan:TOBYINK';
-	$Plack::Middleware::Auth::WebID::VERSION   = '1.910_02';
+	$Plack::Middleware::Auth::WebID::VERSION   = '1.910_03';
 }
 
 use strict;
@@ -49,7 +49,7 @@ sub call
 	my $cert  = $env->{ $self->certificate_env_key }
 		or return $self->$unauth($env);
 	
-	my ($webid, $was_cached) = $self->_get_webid($cert);
+	my ($webid, $was_cached) = $self->_get_webid($cert, $env);
 	
 	if ($webid->valid)
 	{
@@ -57,12 +57,20 @@ sub call
 		$env->{WEBID_OBJECT}    = $webid unless $self->no_object_please;
 		$env->{WEBID_CACHE_HIT} = $was_cached;
 		
-		return $self->app->($env);
+		return $self->_run_app($env);
 	}
 	
 	return $self->$unauth($env);
 }
 
+sub _run_app
+{
+	my ($self, $env) = @_;
+	my $app = $self->app;
+	@_ = $env;
+	goto $app;
+}
+
 sub _get_webid
 {
 	my ($self, $cert) = @_;
